@@ -18,16 +18,7 @@
 /* Written by Jim Meyering.  */
 
 /* AIX requires this to be the first thing in the file.  */
-#ifdef HAVE_CONFIG_H
-#if defined (CONFIG_BROKETS)
-/* We use <config.h> instead of "config.h" so that a compilation
-   using -I. -I$srcdir will use ./config.h rather than $srcdir/config.h
-   (which it would do because it found this file in $srcdir).  */
 #include <config.h>
-#else
-#include "config.h"
-#endif
-#endif
 
 #ifdef __GNUC__
 #define alloca __builtin_alloca
@@ -317,13 +308,12 @@ usage (status)
     {
       printf ("\
 Usage: %s [OPTION]... [FILE]...\n\
-  or:  %s -C [FILE] [[+]OFFSET [[+]LABEL]]\n\
+  or:  %s --traditional [FILE] [[+]OFFSET [[+]LABEL]]\n\
 ",
 	      program_name, program_name);
       printf ("\
 \n\
   -A, --address-radix=RADIX   decide how file offsets are printed\n\
-  -C, --backward-compatible   trigger older syntax\n\
   -N, --read-bytes=BYTES      limit dump to BYTES input bytes per file\n\
   -j, --skip-bytes=BYTES      skip BYTES input bytes first on each file\n\
   -s, --strings[=BYTES]       output strings of at least BYTES graphic chars\n\
@@ -331,6 +321,7 @@ Usage: %s [OPTION]... [FILE]...\n\
   -v, --output-duplicates     do not use * to mark line suppression\n\
   -w, --width[=BYTES]         output BYTES bytes per output line\n\
       --help                  display this help and exit\n\
+      --traditional           accept arguments in pre-POSIX form\n\
       --version               output version information and exit\n\
 \n\
 Pre-POSIX format specifications may be intermixed, they accumulate:\n\
@@ -421,6 +412,7 @@ my_strtoul (s, base, val, allow_bkm_suffix)
 
   assert (0 <= base && base <= 36);
 
+  errno = 0;
   tmp = strtoul (s, &p, base);
   if (errno != 0)
     return UINT_OVERFLOW;
@@ -1040,9 +1032,10 @@ decode_format_string (s)
 /* Given a list of one or more input filenames FILE_LIST, set the global
    file pointer IN_STREAM to position N_SKIP in the concatenation of
    those files.  If any file operation fails or if there are fewer than
-   N_SKIP bytes in the combined input, give an error message and exit.
-   When possible, use seek- rather than read operations to advance
-   IN_STREAM.  A file name of "-" is interpreted as standard input.  */
+   N_SKIP bytes in the combined input, give an error message and return
+   non-zero.  When possible, use seek- rather than read operations to
+   advance IN_STREAM.  A file name of "-" is interpreted as standard
+   input.  */
 
 static int
 skip (n_skip)
@@ -1084,7 +1077,7 @@ skip (n_skip)
 	   - the file must be seekable.
 	   - before seeking to the specified position, make sure
 	     that the new position is in the current file.
-	     Try to do that by getting file's size using stat().
+	     Try to do that by getting file's size using fstat().
 	     But that will work only for regular files and dirs.  */
 
       if (fstat (fileno (in_stream), &file_stats))
@@ -1495,6 +1488,10 @@ dump ()
   size_t n_bytes_read;
   size_t end_offset;
 
+#ifdef lint  /* Suppress `used before initialized' warning.  */
+  end_offset = 0;
+#endif
+
   block[0] = (char *) alloca (bytes_per_block);
   block[1] = (char *) alloca (bytes_per_block);
 
@@ -1702,6 +1699,10 @@ main (argc, argv)
      after any true address.  */
   long int pseudo_start;
 
+#ifdef lint  /* Suppress `used before initialized' warning.  */
+  pseudo_start = 0;
+#endif
+
   program_name = argv[0];
   err = 0;
 
@@ -1862,7 +1863,7 @@ main (argc, argv)
 
   if (show_version)
     {
-      printf ("%s\n", version_string);
+      printf ("od - %s\n", version_string);
       exit (0);
     }
 
@@ -1993,6 +1994,8 @@ main (argc, argv)
     }
 
   err |= skip (n_bytes_to_skip);
+  if (in_stream == NULL)
+    goto cleanup;
 
   pseudo_offset = (flag_pseudo_start ? pseudo_start - n_bytes_to_skip : 0);
 
@@ -2028,6 +2031,8 @@ main (argc, argv)
 
   err |= (flag_dump_strings ? dump_strings () : dump ());
 
+cleanup:;
+
   if (have_read_stdin && fclose (stdin) == EOF)
     error (2, errno, "standard input");
 
